"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const connections_1 = require("../lib/connections");
const common_1 = require("../lib/common");
const cli_ux_1 = require("cli-ux");
const abap_1 = require("../lib/abap");
class List extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(List);
        try {
            const { id = "", objectType = "", objectName = "" } = args;
            const connection = connections_1.getConnection(id);
            if (!connection)
                throw new Error(`Connection ${id} not defined`);
            const client = await common_1.getClient(connection, flags.password);
            if (!client)
                throw new Error(`Connection ${id} not valid`);
            const objects = await abap_1.list(client, objectType, objectName, message => cli_ux_1.cli.action.start(message), flags.recursive);
            cli_ux_1.cli.action.stop("Done");
            cli_ux_1.cli.table(objects, {
                type: {},
                name: {},
                url: {}
            });
        }
        catch (error) {
            this.log(error.toString());
        }
    }
}
exports.default = List;
List.description = "List objects that would be updated";
List.examples = ["$ abapPretty list MYCONN DEVC/K ZMYPACKAGE"];
List.flags = common_1.COMMONFLAGS;
List.args = common_1.COMMONARGS;
