"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const cli_ux_1 = require("cli-ux");
const connections_1 = require("../lib/connections");
const common_1 = require("../lib/common");
const abap_1 = require("../lib/abap");
const main_1 = require("../main");
class Pretty extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(Pretty);
        try {
            const { id = "", objectType = "", objectName = "" } = args;
            const connection = connections_1.getConnection(id);
            if (!connection)
                throw new Error(`Connection ${id} not defined`);
            const client = await common_1.getClient(connection, flags.password);
            if (!client)
                throw new Error(`Connection ${id} not valid`);
            const objects = await abap_1.list(client, objectType, objectName, message => cli_ux_1.cli.action.start(message), flags.recursive);
            cli_ux_1.cli.action.stop("Done");
            await main_1.processObjects(client, objects, {
                test: false,
                transport: flags.transport
            });
        }
        catch (error) {
            this.log(error.toString());
        }
    }
}
exports.default = Pretty;
Pretty.description = "Pretty prints every supported include file in the selected range";
Pretty.examples = ["$ abapPretty prettyprint MYCONN DEVC/K ZMYPACKAGE"];
Pretty.flags = common_1.ALLCOMMONFLAGS;
Pretty.args = common_1.COMMONARGS;
