"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const cli_ux_1 = require("cli-ux");
const connections_1 = require("../lib/connections");
const common_1 = require("../lib/common");
const abap_1 = require("../lib/abap");
const main_1 = require("../main");
class Simulate extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(Simulate);
        try {
            const { id = "", objectType = "", objectName = "" } = args;
            const connection = connections_1.getConnection(id);
            if (!connection)
                throw new Error(`Connection ${id} not defined`);
            const client = await common_1.getClient(connection, flags.password);
            if (!client)
                throw new Error(`Connection ${id} not valid`);
            const objects = await abap_1.list(client, objectType, objectName, message => cli_ux_1.cli.action.start(message), flags.recursive);
            cli_ux_1.cli.action.stop("Done");
            await main_1.processObjects(client, objects, {
                test: true,
                transport: flags.transport
            });
        }
        catch (error) {
            this.log(error.toString());
        }
    }
}
exports.default = Simulate;
Simulate.description = "Simulate updates: perform all actions except writing the formatted source and activating";
Simulate.examples = ["$ abapPretty simulate MYCONN DEVC/K ZMYPACKAGE"];
Simulate.flags = common_1.ALLCOMMONFLAGS;
Simulate.args = common_1.COMMONARGS;
